declare type APISuccessResponse = import("../../../lib/Result").APISuccessResponse;
declare type APIErrorResponse = import("../../../lib/Result").APIErrorResponse;
declare type DatabaseResult = import("../../../lib/Result").DatabaseResult;
declare type DataSourceHierarchy = import("../../../lib/DataSource").DataSourceHierarchy;
declare type ConstructAPIFunction = import("../../../lib/DataSource").ConstructAPIFunction;
declare type EntitySpec = import("../../../lib/Command").EntitySpec;
declare type ParameterSpec = import("../../../lib/Command").ParameterSpec;
declare type EntityType = import("../../../lib/Command").EntityType;
declare type RequestProcessingFunction = import("../../../lib/DataSource").RequestProcessingFunction;
declare type BatchRequestProcessingFunction = import("../../../lib/DataSource").BatchRequestProcessingFunction;
declare namespace Transit {
    type AuthToken = string;
    type EntityRef = string;
    type EntityOptions = {
        entity?: string;
        wait?: boolean;
        single?: boolean;
        editable?: boolean;
        autosave?: boolean;
        args?: EntityArgs;
        onload?: Function;
        onsave?: Function;
        onloaderror?: Function;
        onsaveerror?: Function;
    };
    type EntityStatus = {
        unused: boolean;
        edited: boolean;
        loading: boolean;
        saving: boolean;
        complete: boolean;
        error: string;
        pageCount: number;
    };
    type EntityArgs = {
        [key: string]: any;
    };
    type Row = {
        [key: string]: any;
    };
    type BatchEntry = [string, Object];
    type RequestSpec = {
        ref: EntityRef;
        batchCount: number;
        version?: number;
        resolve?: Function;
        reject?: Function;
    };
    type Editable = {
        [key: string]: any;
        $previous: null | Editable;
        $ref: EntityRef;
        $new: boolean;
        $alive: boolean;
    };
    function loadNamespaceList(authToken?: string): Promise<{}>;
    function loadNamespace(ns: string): Promise<Namespace>;
    class Namespace {
        name: string;
        hierarchy: DataSourceHierarchy;
        api: any;
        authToken: AuthToken;
        entities: {
            [key: string]: Entity;
        };
        loadRequests: RequestSpec[];
        vue: any;
        initResolve: Function | null;
        initReject: Function | null;
        oninitPromise: Promise<void>;
        onautherror: Function;
        constructor(name: string, hierarchy: DataSourceHierarchy);
        makeEntity(ref: string, options: EntityOptions): Entity;
        vueMixin(specs: {
            [key: string]: EntityOptions;
        }): any;
        findRef(ref: EntityRef | Editable[]): EntityRef;
        load(ref: EntityRef | Editable[]): Promise<any>;
        save(...refs: (EntityRef | Editable[])[]): Promise<any>;
        revert(...refs: (EntityRef | Editable[])[]): Promise<void>;
        truncate(...refs: (EntityRef | Editable[])[]): Promise<any>;
        isUnique(row: Row): boolean;
        csv(ref: EntityRef | Editable[]): string;
        count(ref: EntityRef | Editable[]): number;
        scheduleLoadRequest(ref: EntityRef, returnPromise: boolean): Promise<any> | null;
        processLoadRequests(): Promise<void>;
        processSaveRequest(refs: EntityRef[]): Promise<void>;
        processTruncateRequest(refs: EntityRef[]): Promise<void>;
        requestQueue: any[];
        callServerAuthed(path: string, args?: Object): Promise<APISuccessResponse | APIErrorResponse>;
    }
    class Entity {
        ref: string;
        parent: Namespace;
        URLName: string;
        spec: EntitySpec;
        options: EntityOptions;
        args: EntityArgs;
        status: EntityStatus;
        loadRequested: boolean;
        loadRequestSequence: number;
        autosaveSequence: number;
        keySequence: number;
        rows: Row[];
        singleRow: Row;
        removed: Editable[];
        updating: boolean;
        revertJSON: string;
        onload?: Function;
        onloaderror?: Function;
        onsave?: Function;
        onsaveerror?: Function;
        constructor(ref: EntityRef, ns: Namespace, spec: EntitySpec, options: EntityOptions);
        configureResult(): void;
        loadOp(): string;
        parameterSpecs(): ParameterSpec[];
        makeLoadBatchItems(args: EntityArgs): [BatchEntry];
        processLoadResponseItems(items: any[]): Row[] | Row;
        makeTruncateBatchItem(): BatchEntry;
        persistedRowIdentity(row: Row): any[];
        editedRowIdentity(row: Row): any[];
        editedRowIdentityCount(checkRow: Row): number;
        makeInsertBatchItem(row: Editable): BatchEntry;
        makeUpdateBatchItem(row: Editable): BatchEntry;
        makeDeleteBatchItem(row: Editable): BatchEntry;
        result(): Row[] | Row;
        resultAsRows(): Row[];
        markRevertPoint(): void;
        replaceResult(rows: any[]): Row[] | Row;
        markEdited(): Promise<void>;
        revert(): Promise<void>;
        initRow(row: {
            [key: string]: any;
        }): {
            [key: string]: any;
        };
        initRows(rows: Row[]): Row[];
        extendRows(rows: Row[]): void;
        observeRows(rows: Editable[]): Editable[];
        csv(): string;
    }
    function callServer(path: string, args?: Object, authToken?: AuthToken): Promise<APISuccessResponse | APIErrorResponse>;
    function isSuccess(response: APISuccessResponse | APIErrorResponse): response is APISuccessResponse;
    function delay(ms: number): Promise<{}>;
}
/**API_CONSTRUCTOR**/
