export declare type EntityType = 'table' | 'view' | 'procedure' | 'function';
export declare enum DataType {
    Null = 0,
    Boolean = 1,
    Integer = 2,
    Float = 3,
    String = 4,
    Date = 5,
    DateTime = 6,
    Array = 7,
    Object = 8,
    Any = 9
}
export interface EntitySpec {
    readonly name: string;
    readonly type: EntityType;
    readonly identity: FieldSpec[];
    readonly impl: any;
    readonly operations: {
        [key: string]: OperationSpec;
    };
}
export interface OperationSpec {
    readonly name: string;
    readonly parameters: ParameterSpec[];
    readonly outputs: OutputSpec[];
}
export interface FieldSpec {
    readonly name: string;
    readonly dataType: DataType;
    readonly implType?: string;
}
export interface ParameterSpec {
    readonly spec: FieldSpec;
    readonly required: boolean;
    readonly subparams: ParameterSpec[];
}
export interface OutputSpec {
    readonly spec: FieldSpec;
    readonly writeable: boolean;
}
export interface CommandSpec {
    readonly entity: EntitySpec;
    readonly operation: OperationSpec;
}
export declare type EntityNameEscaper = (entityName: string) => string;
export declare type EntityNamespacer = (entity: EntitySpec) => string;
export declare class Command {
    readonly spec: CommandSpec;
    readonly args: any;
    constructor(spec: CommandSpec, args: any[]);
    validateArgument(param: ParameterSpec, inarg: any): any;
    static normalizeName(name: string, env: Object): string;
}
export declare class EntityBuilder {
    private resolve;
    private reject;
    readonly promise: Promise<EntitySpec[]>;
    protected entities: {
        [key: string]: EntitySpec;
    };
    protected currentEntity: EntitySpec;
    protected currentOperation: OperationSpec;
    protected currentParameter: ParameterSpec;
    entity(name: string, type: EntityType, impl: any): EntityBuilder;
    operation(name: string): EntityBuilder;
    identity(name: string, dataType: DataType, implType: string): void;
    parameter(name: string, dataType: DataType, implType: string | undefined, required: boolean): EntityBuilder;
    subparam(name: string, dataType: DataType, implType: string | undefined, required: boolean): EntityBuilder;
    output(name: string, dataType: DataType, implType: string | undefined, writeable: boolean): EntityBuilder;
    outputOne(name: string, dataType: DataType): void;
    done(): void;
}
export declare class DatabaseEntityBuilder extends EntityBuilder {
    proc(): void;
    procParameter(name: string, dataType: DataType, implType: string, required: boolean): void;
    procOutput(name: string, dataType: DataType, implType: string): void;
    tableColumn(name: string, dataType: DataType, implType: string, required: boolean, primaryKey: boolean, writeable: boolean): EntityBuilder;
    viewColumn(name: string, dataType: DataType, implType: string): EntityBuilder;
    column(name: string, dataType: DataType, implType: string, writeable: boolean): EntityBuilder;
}
