/// <reference types="node" />
import * as http from "http";
export declare type IdentityConfig = {
    driver: string;
    config: {
        [key: string]: any;
    };
    namespacesKey?: string;
};
export interface IdentityDriver {
    obtainCredentials(request: http.IncomingMessage): IdentityCredentials | null;
    validateCredentials(credentials: IdentityCredentials): Identity | null;
    obtainIdentity(request: http.IncomingMessage, response: http.ServerResponse): Promise<Identity | null>;
    identityCredentials(identity: Identity): any;
    configureFailureResponse(response: http.ServerResponse): any;
}
export declare type IdentityCredentials = any;
export declare type Identity = {
    username?: string;
    roles: string[];
};
export declare abstract class IdentityDriverBase implements IdentityDriver {
    obtainCredentials(request: http.IncomingMessage): IdentityCredentials | null;
    abstract validateCredentials(credentials: IdentityCredentials): Identity | null;
    obtainIdentity(request: http.IncomingMessage, response: http.ServerResponse): Promise<Identity | null>;
    identityCredentials(credentials: IdentityCredentials): void;
    configureFailureResponse(response: http.ServerResponse): void;
}
export declare function loadIdentitySource(config: IdentityConfig): IdentityDriver;
