"use strict";
/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const rotating_file_stream_1 = require("rotating-file-stream");
var logs = {
    event: null,
    api: null,
    doc: null,
};
exports.enabled = true;
var lastMessage = "";
var lastMessageCount = 1;
function makeLogger(name, file) {
    if (file) {
        let path = './';
        if (file.match(/^(.*)\/([^\/]+)$/)) {
            path = RegExp.$1;
            file = RegExp.$2;
        }
        let pad = (n) => n < 10 ? '0' + n : n;
        logs[name] = rotating_file_stream_1.default((t, i) => file + (t ? `.${t.getFullYear()}-${pad(t.getMonth() + 1)}-${pad(t.getDate())}` : ""), { path: path, interval: "1d" });
        logs[name].on("error", (err) => {
            console.log(`${new Date().toISOString()} Error logging ${name} to ${file}, ${name} logging disabled: ${err}`);
            logs[name] = null;
        });
    }
    else {
        logs[name] = null;
    }
}
function configureEvent(file) {
    makeLogger("event", file);
}
exports.configureEvent = configureEvent;
function configureAPI(file) {
    makeLogger("api", file);
}
exports.configureAPI = configureAPI;
function configureDocument(file) {
    makeLogger("doc", file);
}
exports.configureDocument = configureDocument;
function writeEventArgs(level, pargs) {
    if (exports.enabled) {
        let newMessage = Array.prototype.slice.call(pargs).join(" ");
        if (newMessage == lastMessage) {
            lastMessageCount++;
        }
        else {
            if (lastMessageCount > 1) {
                console.log(`(repeated ${lastMessageCount == 2 ? 'once' : (lastMessageCount - 1) + ' times'})`);
            }
            lastMessageCount = 1;
            lastMessage = newMessage;
            let fullMessage = `${new Date().toISOString()} ${level} ${newMessage}`;
            console.log(fullMessage);
            if (logs.event) {
                logs.event.write(fullMessage);
                logs.event.write("\n");
            }
        }
    }
}
function error(...any) {
    writeEventArgs("error", arguments);
}
exports.error = error;
function warn(...any) {
    writeEventArgs("warn", arguments);
}
exports.warn = warn;
function info(...any) {
    writeEventArgs("info", arguments);
}
exports.info = info;
function writeTransaction(logger, req, res) {
    if (exports.enabled) {
        if (logger) {
            logger.write(new Date().toISOString());
            logger.write(" ");
            logger.write(String(res.statusCode));
            logger.write(" ");
            logger.write(String(req.url));
            logger.write("\n");
        }
    }
}
function api(req, res) {
    writeTransaction(logs.api, req, res);
}
exports.api = api;
function document(req, res) {
    writeTransaction(logs.doc, req, res);
}
exports.document = document;
//# sourceMappingURL=Logger.js.map