"use strict";
/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const log = require("./Logger");
class OperationNotifier {
    constructor() {
        let resolver = null;
        let rejecter = null;
        this.promise = new Promise((resolve, reject) => {
            resolver = resolve;
            rejecter = reject;
        });
        this.resultHandler = (result) => { resolver && resolver(result); };
        this.errorHandler = (error) => { rejecter && rejecter(error); };
    }
    sendResult(r) {
        this.resultHandler(r);
        this._clearHandlers();
    }
    sendError(err, debugInfo) {
        log.error(`Execution failed with error:\n--- start of error\n${err.stack}\n--- end of error\n${debugInfo ? `Debug info: ${debugInfo}` : ''}`);
        this.errorHandler(err);
        this._clearHandlers();
    }
    cancel() {
        this._clearHandlers();
    }
    _clearHandlers() {
        this.resultHandler = (r) => { };
        this.errorHandler = (e) => { };
    }
}
exports.OperationNotifier = OperationNotifier;
class DatabaseResultNotifier extends OperationNotifier {
    constructor() {
        super();
    }
    /*
    sendColumns(c : Columns) {}
    sendRows(r : Row[]) {}
    sendComplete() {}
    */
    _clearHandlers() {
        super._clearHandlers();
    }
}
exports.DatabaseResultNotifier = DatabaseResultNotifier;
//# sourceMappingURL=Result.js.map