/// <reference types="node" />
import * as http from "http";
import { DataSourceConfig, DataSourceFinder, RequestProcessingFunction, BatchRequestProcessingFunction, DataSource } from "./DataSource";
import { APISuccessResponse, APIErrorResponse } from "./Result";
import { Identity, IdentityConfig, IdentityDriver } from "./IdentitySource";
export interface ServerConfig {
    port: number;
    contentDir: string;
    identity: IdentityConfig | null;
    namespaces: DataSourceConfig[];
    clientConfig?: any;
    eventLog?: string;
    apiLog?: string;
    documentLog?: string;
}
export interface Server extends http.Server {
    runtime: ServerRuntime;
}
interface FileContent {
    contentType: string;
    modified: number;
    content: Buffer;
}
export declare function startServer(configArg: ServerConfig | string): Promise<Server>;
export declare function startRuntime(configArg: ServerConfig | string): Promise<ServerRuntime>;
export declare function generateAPI(configArg: ServerConfig | string, ns: string): Promise<any>;
export declare function parseConfig(configArg: ServerConfig | string): ServerConfig;
export declare class ServerRuntime {
    private static _instance;
    config: ServerConfig;
    identitySource: IdentityDriver | null;
    dataSourceFinder: DataSourceFinder;
    configFileRegExp: RegExp;
    namespacesRegExp: RegExp;
    apiFileRegExp: RegExp;
    apiPathRegExp: RegExp;
    apiJSTemplate: string;
    apiHTMLTemplate: string;
    constructor(config: ServerConfig);
    static getInstance(): ServerRuntime;
    start(): Promise<ServerRuntime>;
    processSiteRequest(request: http.IncomingMessage, response: http.ServerResponse): Promise<void>;
    authorizedNamespaces(request: http.IncomingMessage): Promise<string[]>;
    isAuthorized(request: http.IncomingMessage, response: http.ServerResponse, ds: DataSource): Promise<Identity | null>;
    writeSuccessResponse(response: http.ServerResponse, result: APISuccessResponse): void;
    makeAPIErrorResponse(status: number, externalMessage: string, internalMessage?: string): APIErrorResponse;
    validateAPIRequest(ds: DataSource, entity: string, operation: string, data: any): APIErrorResponse | null;
    call: RequestProcessingFunction;
    callBatch: BatchRequestProcessingFunction;
    getAPI(ns: string): any;
    generateAPIJavaScript(ns: string): string;
    generateAPIHTML(ns: string): string;
    executeSQL(dsName: string, sql: string, ...args: any[]): Promise<any>;
    insertMacros(dir: string, file: FileContent, openToken: string, closeToken: string): Promise<void>;
}
export {};
