"use strict";
/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const IdentitySource_1 = require("../../lib/IdentitySource");
const log = require("../../lib/Logger");
const jwt = require("jsonwebtoken");
const fs = require("fs");
function createDriver(config) {
    let drv = new Driver();
    drv.init(config);
    return drv;
}
exports.createDriver = createDriver;
class Driver extends IdentitySource_1.IdentityDriverBase {
    init(config) {
        this.config = config;
        this.pem = fs.readFileSync(config.pem).toString();
    }
    validateCredentials(credentials) {
        try {
            var auth = jwt.verify(credentials, this.pem, this.config);
            var username = auth[this.config.usernameKey];
            var roles = auth[this.config.rolesKey];
            if (!Array.isArray(roles)) {
                throw new Error("jwt does not contain an array for the rolesKey");
            }
            return {
                username: username,
                roles: roles
            };
        }
        catch (e) {
            log.warn(`Unable to verify Auth0 credentials: ${e.stack}`);
            return null;
        }
    }
}
//# sourceMappingURL=Auth0.js.map