/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only. 
 */

import * as http from "http";

export type IdentityConfig = {
    driver : string,
    config: { [key: string] : any },
    namespacesKey?: string
}

export interface IdentityDriver {
    obtainCredentials(request : http.IncomingMessage) : IdentityCredentials | null;
    validateCredentials(credentials : IdentityCredentials) : Identity | null;
    obtainIdentity(request : http.IncomingMessage, response : http.ServerResponse) : Promise<Identity|null>;
    identityCredentials(identity : Identity);
    configureFailureResponse(response : http.ServerResponse);
}

export type IdentityCredentials = any;

export type Identity = {
    username?: string,
    roles: string[]
 };

export abstract class IdentityDriverBase implements IdentityDriver {
    obtainCredentials(request : http.IncomingMessage) : IdentityCredentials | null {
        return Promise.resolve(request.headers["x-transit-authorization"] || null);
    }

    abstract validateCredentials(credentials : IdentityCredentials) : Identity | null;

    obtainIdentity(request : http.IncomingMessage, response : http.ServerResponse) : Promise<Identity|null> {
        return Promise.resolve(null);
    }

    identityCredentials(credentials : IdentityCredentials) {
        // in most auth modules, this will never get called
        throw new Error("not implemented");
    }

    configureFailureResponse(response : http.ServerResponse) {
        response.statusCode = 401;
    }
}

export function loadIdentitySource(config : IdentityConfig) : IdentityDriver {
    let driverPath = config.driver.match(/^[\w\d]+$/) ? __dirname + "/identity/" + config.driver : config.driver;
    return (<any>require).main.require(driverPath).createDriver(config.config);
}
