/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only. 
 */

import * as http from "http";
import rfs from "rotating-file-stream";
import * as stream from "stream";

var logs : { 
    event:stream.Writable|null; 
    api:stream.Writable|null; 
    doc:stream.Writable|null; 
} = { 
    event: null, 
    api: null, 
    doc: null,
};

export var enabled: boolean = true;
var lastMessage:string = "";
var lastMessageCount = 1;

function makeLogger(name:string, file:string) {
    if (file) {
        let path = './';
        if (file.match(/^(.*)\/([^\/]+)$/)) {
            path = RegExp.$1;
            file = RegExp.$2;
        }
        let pad = (n) => n < 10 ? '0' + n : n;
        logs[name] = rfs(
            (t,i) => file + (t ? `.${t.getFullYear()}-${pad(t.getMonth()+1)}-${pad(t.getDate())}` : ""), 
            { path: path, interval: "1d" }
        );
        logs[name].on("error", (err) => {
            console.log(`${new Date().toISOString()} Error logging ${name} to ${file}, ${name} logging disabled: ${err}`);
            logs[name] = null;
        });
    } else {
        logs[name] = null;
    }
}

export function configureEvent(file : string) {
    makeLogger("event", file);
}

export function configureAPI(file : string) {
    makeLogger("api", file);
 }

export function configureDocument(file : string) {
    makeLogger("doc", file);
}

function writeEventArgs(level, pargs) {
    if (enabled) {
        let newMessage = Array.prototype.slice.call(pargs).join(" ");
        if (newMessage == lastMessage) {
            lastMessageCount++;
        } else {
            if (lastMessageCount > 1) {
                console.log(`(repeated ${lastMessageCount == 2 ? 'once' : (lastMessageCount-1) + ' times'})`);
            }
            lastMessageCount = 1;
            lastMessage = newMessage;

            let fullMessage = `${new Date().toISOString()} ${level} ${newMessage}`;
            console.log(fullMessage);
            if (logs.event) {
                logs.event.write(fullMessage);
                logs.event.write("\n");
            }
        }
    }
}

export function error(...any) {
    writeEventArgs("error", arguments);
}

export function warn(...any) {
    writeEventArgs("warn", arguments);
}

export function info(...any) {
    writeEventArgs("info", arguments);
}

function writeTransaction(logger : stream.Writable|null, req : http.IncomingMessage, res : http.ServerResponse) {
    if (enabled) {
        if (logger) {
            logger.write(new Date().toISOString());
            logger.write(" ");
            logger.write(String(res.statusCode));
            logger.write(" ");
            logger.write(String(req.url));
            logger.write("\n");
        }
    }
}

export function api(req : http.IncomingMessage, res : http.ServerResponse) {
    writeTransaction(logs.api, req, res);
}
export function document(req : http.IncomingMessage, res : http.ServerResponse) {
    writeTransaction(logs.doc, req, res);
}
