/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only. 
 */


import { IdentityDriver, IdentityDriverBase, IdentityCredentials, Identity } from "../../lib/IdentitySource";
import * as http from "http";
import * as crypto from "crypto";

export function createDriver(config) : IdentityDriver {
    let drv = new Driver().init(config);
    return drv;
}

class Driver extends IdentityDriverBase {
    config : any;
    sspi : any;
    cryptoKey : Buffer;
    cipher: crypto.Cipher;
    decipher: crypto.Decipher;
    
    init(config) : Driver {
        this.config = config;
        import("node-sspi"!).then((sspi) => {
            this.sspi = new sspi({
                retrieveGroups: true,
                offerBasic: false,
                authoritative: false
            });
        });
        crypto.randomBytes(256, (err, buf) => {
            if (err) throw err;
            this.cryptoKey = buf;
        });
        return this;
    }

    validateCredentials(credentials : IdentityCredentials) : Identity | null {
        try {
            var decipher = crypto.createDecipher('aes256', this.cryptoKey);
            var deciphered = decipher.update(credentials, 'hex', 'utf8');
            let ident = JSON.parse(deciphered + decipher.final('utf8'));
            if (typeof ident.username == "string" && Array.isArray(ident.roles)) {
                return ident;
            }
        } catch(e) {
        }
        return null;
    }

    obtainIdentity(request : http.IncomingMessage, response : http.ServerResponse) : Promise<Identity|null> {
        return new Promise((resolve, reject) => {
            this.sspi.authenticate(request, response, function(err) {
                let user = request.connection["user"];
                let roles = request.connection["userGroups"];
                if (user && roles) { 
                    resolve({ username: user, roles: roles });
                } else {
                    resolve(null);
                }
            })
        });
    }

    identityCredentials(identity : Identity) : IdentityCredentials {
        try {
            let cipher = crypto.createCipher('aes256', this.cryptoKey);
            let creds =  cipher.update(JSON.stringify(identity), 'utf8', 'hex') + cipher.final('hex');
            return creds;
        } catch(e) {
            return null;
        }
    }

    configureFailureResponse(response : http.ServerResponse) {
        // might already be configured in obtainIdentity
        if (response.statusCode == 200) {
        	response.statusCode = 401;
        }
    }
}