/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only. 
 */


import { IdentityDriver, IdentityDriverBase, IdentityCredentials, Identity } from "../../lib/IdentitySource";
import * as log from "../../lib/Logger";
import * as jwt from "jsonwebtoken";
import * as fs from "fs";

export function createDriver(config) : IdentityDriver {
    let drv = new Driver();
    drv.init(config);
    return drv;
}

class Driver extends IdentityDriverBase {
    config : any;
    pem : string;

    init(config) {
        this.config = config;
        this.pem = fs.readFileSync(config.pem).toString();
    }

    validateCredentials(credentials : IdentityCredentials) : Identity | null {
        try {
            var auth = jwt.verify(credentials, this.pem, this.config);
            var username = auth[this.config.usernameKey];
            var roles = auth[this.config.rolesKey];
            if (!Array.isArray(roles)) {
                throw new Error("jwt does not contain an array for the rolesKey");
            }
            return {
                username: username,
                roles: roles
            };
        } catch (e) {
            log.warn(`Unable to verify Auth0 credentials: ${e.stack}`);
            return null;
        }
    }
}