/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only. 
 */


import { IdentityDriver, IdentityDriverBase, IdentityCredentials, Identity } from "../../lib/IdentitySource";
import * as log from "../../lib/Logger";

export function createDriver(config) : IdentityDriver {
    return new Driver().init(config);
}

class Driver extends IdentityDriverBase {
    config : any;
    pem : string;

    init(config) : Driver {
        this.config = config;
        for (let user of this.config.users) {
            if (!Array.isArray(user.roles)) {
                throw new Error(`roles is not an Array: ${user.roles}`);
            }
        }
        return this;
    }

    validateCredentials(credentials : IdentityCredentials) : Identity | null {
        try {
            let credsObj = JSON.parse(Buffer.from(credentials, "base64").toString());
            for (let user of this.config.users) {
                if (credsObj.username == user.username) {
                    if (credsObj.password == user.password) {
                        return {
                            username: user.username,
                            roles: user.roles
                        };
                    } else {
                        return null;
                    }
                }
            }
            return null;
        } catch(e) {
            log.warn(`Auth error: ${e.stack || e}`);
            return null;
        }
    }
}