/*
 * Copyright 2019 Quadrant LLC. (http://quadrant.agency/)
 *
 * This file is part of Quadrant Transit.
 *
 * Quadrant Transit is distributed without license for evaluation purposes only. 
 */

CREATE OR ALTER PROCEDURE [echo_types[]]] 
	@bigint bigint,
	@bit bit,
	@char char(3),
	@date date,
	@datetime datetime,
	@datetime2 datetime2(7),
	@datetimeoffset datetimeoffset(7),
	@decimal decimal(3, 2),
	@float float,
	@int int,
	@money money,
	@nchar nchar(3),
	@ntext ntext,
	@numeric numeric(3, 2),
	@nvarchar nvarchar(50),
	@real real,
	@smalldatetime smalldatetime,
	@smallint smallint,
	@smallmoney smallmoney,
	@text text,
	@time time(7),
	@tinyint tinyint,
	@uniqueidentifier uniqueidentifier,
	@varchar varchar(50)	
WITH EXECUTE AS 'dbo'
AS
BEGIN
	SELECT 
		@bigint AS 'col bigint', 
		@bit AS 'col bit', 
		@char AS 'col char', 
		@date AS 'col date', 
		@datetime AS 'col datetime', 
		@datetime2 AS 'col datetime2', 
		@datetimeoffset AS 'col datetimeoffset',
		@decimal AS 'col decimal',
		@float AS 'col float',
		@int AS 'col int',
		@money AS 'col money',
		@nchar AS 'col nchar',
		@ntext AS 'col ntext',
		@numeric AS 'col numeric',
		@nvarchar AS 'col nvarchar',
		@real AS 'col real',
		@smalldatetime AS 'col smalldatetime',
		@smallint AS 'col smallint',
		@smallmoney AS 'col smallmoney',
		@text AS 'col text',
		@time AS 'col time',
		@tinyint AS 'col tinyint',
		@uniqueidentifier AS 'col uniqueidentifier',
		@varchar AS 'col varchar';
	RETURN;
END
GO

-- test the above proc...
EXEC 
	[echo_types[]]] 
	3,
	1,
	'xyz',
	'2018-01-01',
	'2018-01-01T13:12:11.000',
	'2018-01-01T13:12:11.0000000',
	'2018-01-01T08:12:11.0000000-05:00',
	3.14,
	3.14,
	3,
	3.1400,
	'xyz',
	'xyz',
	3.14,
	'xyz',
	3.14,
	'2018-01-01T13:12:00',
	3,
	3.14,
	'xyz',
	'13:12:11',
	3,
	'c15c77f2-aaeb-4629-84cf-76aad3746c8c',
	'xyz';
GO

CREATE OR ALTER PROCEDURE echo 
	@message nvarchar(max)
WITH EXECUTE AS 'dbo'
AS
BEGIN
	SELECT 
		@message AS 'message'
	RETURN;
END
GO

-- test the above proc...
EXEC echo 'foo';

CREATE TABLE [dbo].[All Datatypes[]]](
	[col bigint] [bigint] NULL,
	[col bit] [bit] NULL,
	[col char] [char](3) NULL,
	[col date] [date] NULL,
	[col datetime] [datetime] NULL,
	[col datetime2] [datetime2](7) NULL,
	[col datetimeoffset] [datetimeoffset](7) NULL,
	[col decimal] [decimal](3, 2) NULL,
	[col float] [float] NULL,
	[col int] [int] NULL,
	[col money] [money] NULL,
	[col nchar] [nchar](3) NULL,
	[col ntext] [ntext] NULL,
	[col numeric] [numeric](3, 2) NULL,
	[col nvarchar] [nvarchar](50) NULL,
	[col real] [real] NULL,
	[col smalldatetime] [smalldatetime] NULL,
	[col smallint] [smallint] NULL,
	[col smallmoney] [smallmoney] NULL,
	[col text] [text] NULL,
	[col time] [time](7) NULL,
	[col tinyint] [tinyint] NULL,
	[col uniqueidentifier] [uniqueidentifier] NULL,
	[col varchar] [varchar](50) NULL
);
GO

INSERT [dbo].[All Datatypes[]]] 
	([col bigint], [col bit], [col char], [col date], [col datetime], [col datetime2], [col datetimeoffset], [col decimal], [col float], [col int], [col money], [col nchar], [col ntext], [col numeric], [col nvarchar], [col real], [col smalldatetime], [col smallint], [col smallmoney], [col text], [col time], [col tinyint], [col uniqueidentifier], [col varchar]) 
VALUES 
	(3, 1, N'xyz', CAST(N'2018-01-01' AS Date), CAST(N'2018-01-01T13:12:11.000' AS DateTime), CAST(N'2018-01-01T13:12:11.0000000' AS DateTime2), CAST(N'2018-01-01T08:12:11.0000000-05:00' AS DateTimeOffset), CAST(3.14 AS Decimal(3, 2)), 3.14, 3, 3.1400, N'xyz', N'xyz', CAST(3.14 AS Numeric(3, 2)), N'xyz', 3.14, CAST(N'2018-01-01T13:12:00' AS SmallDateTime), 3, 3.1400, N'xyz', CAST(N'13:12:11' AS Time), 3, N'c15c77f2-aaeb-4629-84cf-76aad3746c8c', N'xyz')
GO

CREATE OR ALTER VIEW [All Datatypes View[]]] AS
SELECT * FROM [All Datatypes[]]];
GO

CREATE TABLE dbo.test_table (
	int_null int NULL,
	int_not_null_default_0 int NOT NULL DEFAULT 0,
	pk2 int NOT NULL,
	int_not_null int NOT NULL,
	pk1 int NOT NULL,
	PRIMARY KEY (pk1, pk2)
);
GO

CREATE TABLE dbo.simple (
	pk1 int NOT NULL,
	pk2 int NOT NULL,
	str nvarchar(max) NULL,
	num int NULL,
	PRIMARY KEY (pk1, pk2)
);
GO

CREATE TABLE dbo.ident (
	id int NOT NULL IDENTITY(1,1) PRIMARY KEY,
	str nvarchar(max) NULL
);
INSERT INTO dbo.ident (str) VALUES ('foo');
GO

CREATE FUNCTION dbo.echo_fn (@msg nvarchar(50))
RETURNS nvarchar(50)
WITH EXECUTE AS CALLER
BEGIN
	RETURN (@msg);
END
GO

CREATE FUNCTION dbo.echo_tf (@msg nvarchar(50), @num int)
RETURNS @retTbl TABLE
(
	Msg nvarchar(max),
	Num int
)
WITH EXECUTE AS CALLER
BEGIN
	INSERT INTO @retTbl SELECT @msg, @num;
	RETURN;	
END
GO

CREATE TABLE dbo.many_rows (
	num int NOT NULL PRIMARY KEY
);

DECLARE @i int = 0;
WHILE @i < 70000
BEGIN
	INSERT INTO dbo.many_rows (num) VALUES (@i);
	SET @i = @i + 1;
END
GO
